/***************************************************************
 * Name:      wx004Main.cpp
 * Purpose:   Code for Application Frame
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-04-11
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#include "wx004Main.h"
#include "boxsizer.h"
#include "staticboxsizer.h"
#include "stdDialogButtonSizer.h"
#include "wrapsizer.h"
#include "gridsizer.h"
#include "flexgridsizer.h"
#include "gridbagsizer.h"

//helper functions
enum wxbuildinfoformat {
    short_f, long_f };

wxString wxbuildinfo(wxbuildinfoformat format)
{
    wxString wxbuild(wxVERSION_STRING);

    if (format == long_f )
    {
#if defined(__WXMSW__)
        wxbuild << _T("-Windows");
#elif defined(__WXMAC__)
        wxbuild << _T("-Mac");
#elif defined(__UNIX__)
        wxbuild << _T("-Linux");
#endif

#if wxUSE_UNICODE
        wxbuild << _T("-Unicode build");
#else
        wxbuild << _T("-ANSI build");
#endif // wxUSE_UNICODE
    }

    return wxbuild;
}


BEGIN_EVENT_TABLE(wx004Dialog, wxDialog)
    EVT_CLOSE(wx004Dialog::OnClose)
    EVT_BUTTON(idBoxSizer, wx004Dialog::OnBoxSizer)
    EVT_BUTTON(idStaticBoxSizer, wx004Dialog::OnStaticBoxSizer)
    EVT_BUTTON(idStdDialogButtonSizer, wx004Dialog::OnStdDialogButtonSizer)
    EVT_BUTTON(idWrapSizer, wx004Dialog::OnWrapSizer)
    EVT_BUTTON(idGridSizer, wx004Dialog::OnGridSizer)
    EVT_BUTTON(idFlexGridSizer, wx004Dialog::OnFlexGridSizer)
    EVT_BUTTON(idGridBagSizer, wx004Dialog::OnGridBagSizer)
    EVT_BUTTON(idBtnQuit, wx004Dialog::OnQuit)
    EVT_BUTTON(idBtnAbout, wx004Dialog::OnAbout)
END_EVENT_TABLE()

wx004Dialog::wx004Dialog(wxDialog *dlg, const wxString &title)
    : wxDialog(dlg, -1, title, wxDefaultPosition, wxSize(200,wxDefaultCoord), wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER)
{
    wxBoxSizer *boxHorizontal;
    wxWrapSizer *wrapVertical;
    wxButton* boton;

    wxImage::AddHandler(new wxPNGHandler); // Acceso a imágenes PNG

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    wrapVertical = new wxWrapSizer(wxVERTICAL);

    wxBitmapBundle* bmb;
    wxGenericStaticBitmap* m_staticBitmap = new wxGenericStaticBitmap(this, wxID_ANY, bmb->FromFiles("sizers-transparente.png"));
    boxHorizontal->Add(m_staticBitmap);

    boton = new wxButton(this, idBoxSizer, wxT("&Box sizer"));
    wrapVertical->Add(boton, wxSizerFlags().Border());
    boton = new wxButton(this, idStaticBoxSizer, wxT("S&tatic Box sizer"));
    wrapVertical->Add(boton, wxSizerFlags().Border());
    boton = new wxButton(this, idStdDialogButtonSizer, wxT("Std&DlgBut sizer"));
    wrapVertical->Add(boton, wxSizerFlags().Border());
    boton = new wxButton(this, idWrapSizer, wxT("&Wrap sizer"));
    wrapVertical->Add(boton, wxSizerFlags().Border());
    boton = new wxButton(this, idGridSizer, wxT("&Grid sizer"));
    wrapVertical->Add(boton, wxSizerFlags().Border());
    boton = new wxButton(this, idFlexGridSizer, wxT("&FlexGrid sizer"));
    wrapVertical->Add(boton, wxSizerFlags().Border());
    boton = new wxButton(this, idGridBagSizer, wxT("G&ridBag sizer"));
    wrapVertical->Add(boton, wxSizerFlags().Border());

    boton = new wxButton(this, idBtnQuit, wxT("&Salir"));
    wrapVertical->Add(boton, wxSizerFlags().Border());
    boton = new wxButton(this, idBtnAbout, wxT("S&obre"));
    wrapVertical->Add(boton, wxSizerFlags().Border());
    boxHorizontal->Add(wrapVertical);

    SetSizerAndFit(boxHorizontal);
    SetInitialSize();
}

wx004Dialog::~wx004Dialog()
{
}

void wx004Dialog::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void wx004Dialog::OnBoxSizer(wxCommandEvent& event) {
    boxSizer *dlg = new boxSizer(this);
    dlg->ShowModal();
}

void wx004Dialog::OnStaticBoxSizer(wxCommandEvent& event) {
    staticBoxSizer *dlg = new staticBoxSizer(this);
    dlg->ShowModal();
}

void wx004Dialog::OnStdDialogButtonSizer(wxCommandEvent& event) {
    stdDialogButtonSizer *dlg = new stdDialogButtonSizer(this);
    dlg->ShowModal();
}

void wx004Dialog::OnWrapSizer(wxCommandEvent& event) {
    wrapSizer *dlg = new wrapSizer(this);
    dlg->ShowModal();
}

void wx004Dialog::OnGridSizer(wxCommandEvent& event) {
    gridSizer *dlg = new gridSizer(this);
    dlg->ShowModal();
}

void wx004Dialog::OnFlexGridSizer(wxCommandEvent& event) {
    flexGridSizer *dlg = new flexGridSizer(this);
    dlg->ShowModal();
}

void wx004Dialog::OnGridBagSizer(wxCommandEvent& event) {
    gridBagSizer *dlg = new gridBagSizer(this);
    dlg->ShowModal();
}
void wx004Dialog::OnQuit(wxCommandEvent &event)
{
    Destroy();
}

void wx004Dialog::OnAbout(wxCommandEvent &event)
{
    wxString msg = wxbuildinfo(long_f);
    wxMessageBox(msg, _("Bienvenido a..."));
}

